@@ -47,6 +47,7 @@
 #include <QDir>
 #include <QFileInfo>
 #include <QStringBuilder>
+#include <QFileSystemWatcher>
 
 #include "projectmodel.h"
 #include "webquerycontroller.h"
@@ -80,17 +81,17 @@ QString getMailingList()
     if (lang.startsWith(QLatin1String("lt")))
         return QLatin1String("kde-i18n-lt@kde.org");
     if (lang.startsWith(QLatin1String("nb")))
-        return QLatin1String("l10n-no@lister.huftis.org");
+        return QLatin1String("i18n-nb@lister.ping.uio.no");
     if (lang.startsWith(QLatin1String("nl")))
         return QLatin1String("kde-i18n-nl@kde.org");
     if (lang.startsWith(QLatin1String("nn")))
-        return QLatin1String("l10n-no@lister.huftis.org");
+        return QLatin1String("i18n-nn@lister.ping.uio.no");
     if (lang.startsWith(QLatin1String("pt_BR")))
         return QLatin1String("kde-i18n-pt_BR@kde.org");
     if (lang.startsWith(QLatin1String("ru")))
         return QLatin1String("kde-russian@lists.kde.ru");
     if (lang.startsWith(QLatin1String("se")))
-        return QLatin1String("l10n-no@lister.huftis.org");
+        return QLatin1String("i18n-sme@lister.ping.uio.no");
     if (lang.startsWith(QLatin1String("sl")))
         return QLatin1String("lugos-slo@lugos.si");
 
@@ -158,12 +159,14 @@ void Project::load(const QString &newProjectPath, const QString& forcedTargetLan
     TM::threadPool()->clear();
     qCDebug(LOKALIZE_LOG) << "loading" << newProjectPath << "finishing tm jobs...";
 
-    if (!m_path.isEmpty()) {
+    //It is not necessary to close the TM Databases, as they are opened by default for statistics purposes
+    //This just causes issues when changing project because the previous TM is closed
+    /*if (!m_path.isEmpty()) {
         TM::CloseDBJob* closeDBJob = new TM::CloseDBJob(projectID());
         closeDBJob->setAutoDelete(true);
         TM::threadPool()->start(closeDBJob, CLOSEDB);
     }
-    TM::threadPool()->waitForDone(500);//more safety
+    TM::threadPool()->waitForDone(500);//more safety*/
 
     setSharedConfig(KSharedConfig::openConfig(newProjectPath, KConfig::NoGlobals));
     if (!QFileInfo::exists(newProjectPath)) Project::instance()->setDefaults();
@@ -211,6 +214,11 @@ void Project::load(const QString &newProjectPath, const QString& forcedTargetLan
         QaModel::instance()->loadRules(qaPath());
     }
 
+    //Set a watch for config change/reload
+    m_projectFileWatcher = new QFileSystemWatcher(this);
+    m_projectFileWatcher->addPath(newProjectPath);
+    connect(m_projectFileWatcher, &QFileSystemWatcher::fileChanged, Project::instance(), &KCoreConfigSkeleton::load);
+
     //qCDebug(LOKALIZE_LOG)<<"until emitting signal"<<a.elapsed();
 
     emit loaded();
@@ -237,6 +245,17 @@ QString Project::absolutePath(const QString& possiblyRelPath) const
     return possiblyRelPath;
 }
 
+
+QString Project::relativePath(const QString& possiblyAbsPath) const
+{
+    if (QFileInfo(possiblyAbsPath).isAbsolute()) {
+        if (projectDir().endsWith('/'))
+            return QString(possiblyAbsPath).remove(projectDir());
+        return QString(possiblyAbsPath).remove(projectDir() + QLatin1Char('/'));
+    }
+    return possiblyAbsPath;
+}
+
 void Project::populateDirModel()
 {
     if (Q_UNLIKELY(m_path.isEmpty() || !QFileInfo::exists(poDir())))
